@@ -281,9 +281,11 @@ async def django_instance_field_to_redis_value(
             redis_value = None
         else:
             django_foreign_key_instance = django_field_value
+
             if save_related_models:
+                print(1)
                 redis_foreign_key_instance = await get_or_create_redis_instance_from_django_instance(
-                    django_instance,
+                    django_foreign_key_instance,
                     redis_root,
                     save_related_models,
                     get_or_create_redis_model_from_django_model,
@@ -295,9 +297,10 @@ async def django_instance_field_to_redis_value(
     elif django_field.__class__ == django_models.ManyToManyField:
         django_many_to_many_instances = await django_sync_to_async_list(django_field_value.all)
         if save_related_models:
+            print(len(django_many_to_many_instances))
             redis_value = [
                 await get_or_create_redis_instance_from_django_instance(
-                    django_instance,
+                    django_many_to_many_instance,
                     redis_root,
                     save_related_models,
                     get_or_create_redis_model_from_django_model,
